/***************************************************************************
 *   Copyright (C) 2012 by Pino Toscano <pino@kde.org>                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#ifndef SIGMODEL_H
#define SIGMODEL_H

#include <qabstractitemmodel.h>
#include <qdom.h>
#include <qfile.h>
#include <qvector.h>

class SigModel : public QAbstractItemModel
{
    Q_OBJECT
public:
    enum { SignatureRole = Qt::UserRole + 100 };

    SigModel(QObject *parent = 0);
    virtual ~SigModel();

    // QAbstractItemModel reimplementations
    virtual int columnCount(const QModelIndex &parent = QModelIndex()) const;
    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
    virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
    virtual QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const;
    virtual bool insertRows(int row, int count, const QModelIndex &parent = QModelIndex());
    virtual QModelIndex parent(const QModelIndex &index) const;
    virtual bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex());
    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
    virtual bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole);

    void save();

private:
    QString emptySignatureString() const;
    void load(const QString &fileName);
    void updateNode(QDomNode element, const QString &text);

    QFile m_file;
    QDomDocument m_doc;
    QDomElement m_rootElement;
    QDomNodeList m_signatures;
    QVector<QString> m_cachedSignatures;
    mutable QString m_emptySigString;
};

#endif
